package
Version:
v0.0.15
Opens a new window with list of versions in this module.
Published: Jun 12, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Option struct {
Formatter string `snow:"Formatter"`
WithFileLine bool `snow:"WithFileLine"`
FileLineSkip int `snow:"FileLineSkip"`
ErrorLevel logging.Level `snow:"ErrorLevel"`
Filter map[string]logging.Level `snow:"Filter"`
DefaultLevel logging.Level `snow:"DefaultLevel"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.